from fastclip.schemas.AbstractTranscriptComponent import (
    AbstractTranscriptComponent,
)


class Word(AbstractTranscriptComponent):
    """Represents a word in a transcript."""

    word: str
    punctuated_word: str
    start: float
    end: float

    def __repr__(self):
        return f"Word(word='{self.word}', punctuated_word='{self.punctuated_word}', start={self.start}, end={self.end})"

    def to_json(self):
        return {
            "word": self.word,
            "punctuated_word": self.punctuated_word,
            "start": self.start,
            "end": self.end,
        }

    @classmethod
    def from_dict(cls, d):
        return cls(
            word=d["word"],
            punctuated_word=d["punctuated_word"],
            start=d["start"],
            end=d["end"],
        )



from typing import List
from pydantic import BaseModel

from fastclip.enums.ClipFormat import ClipFormat
from fastclip.schemas.Word import Word


class ClipPreviewPayload(BaseModel):
    start: float
    end: float
    subtitles_settings: dict
    subtitles: List[Word] = []
    format: ClipFormat = ClipFormat.HORIZONTAL
    has_subtitles: bool = False

    def to_json(self):
        return {
            "start": self.start,
            "end": self.end,
            "subtitles_settings": self.subtitles_settings,
            "subtitles": [word.to_json() for word in self.subtitles],
            "format": self.format.value,
        }
